=================================
Resolwe module (:mod:`resolwe`)
=================================
.. automodule:: orangecontrib.bioinformatics.resolwe
.. autofunction:: orangecontrib.bioinformatics.resolwe.connect

.. autoclass:: GenAPI()
   :members:


